summaryrefslogtreecommitdiffstats
path: root/chrome/browser/views/frame
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/views/frame')
-rw-r--r--chrome/browser/views/frame/browser_view.cc8
-rw-r--r--chrome/browser/views/frame/browser_view.h10
-rw-r--r--chrome/browser/views/frame/contents_container.h2
3 files changed, 10 insertions, 10 deletions
diff --git a/chrome/browser/views/frame/browser_view.cc b/chrome/browser/views/frame/browser_view.cc
index a2bacef..8c2eea6 100644
--- a/chrome/browser/views/frame/browser_view.cc
+++ b/chrome/browser/views/frame/browser_view.cc
@@ -26,6 +26,7 @@
#include "chrome/browser/debugger/devtools_window.h"
#include "chrome/browser/dom_ui/bug_report_ui.h"
#include "chrome/browser/download/download_manager.h"
+#include "chrome/browser/instant/instant_controller.h"
#include "chrome/browser/ntp_background_util.h"
#include "chrome/browser/page_info_window.h"
#include "chrome/browser/prefs/pref_service.h"
@@ -33,7 +34,6 @@
#include "chrome/browser/sessions/tab_restore_service.h"
#include "chrome/browser/sidebar/sidebar_container.h"
#include "chrome/browser/sidebar/sidebar_manager.h"
-#include "chrome/browser/tab_contents/match_preview.h"
#include "chrome/browser/tab_contents/tab_contents.h"
#include "chrome/browser/tab_contents/tab_contents_view.h"
#include "chrome/browser/tabs/tab_strip_model.h"
@@ -1355,14 +1355,14 @@ void BrowserView::ToggleTabStripMode() {
frame_->TabStripDisplayModeChanged();
}
-void BrowserView::ShowMatchPreview(TabContents* preview_contents) {
+void BrowserView::ShowInstant(TabContents* preview_contents) {
if (!preview_container_)
preview_container_ = new TabContentsContainer();
contents_->SetPreview(preview_container_, preview_contents);
preview_container_->ChangeTabContents(preview_contents);
}
-void BrowserView::HideMatchPreview() {
+void BrowserView::HideInstant() {
if (!preview_container_)
return;
@@ -1373,7 +1373,7 @@ void BrowserView::HideMatchPreview() {
preview_container_ = NULL;
}
-gfx::Rect BrowserView::GetMatchPreviewBounds() {
+gfx::Rect BrowserView::GetInstantBounds() {
return contents_->GetPreviewBounds();
}
diff --git a/chrome/browser/views/frame/contents_container.h b/chrome/browser/views/frame/contents_container.h
index 9a03c38..fe22d47 100644
--- a/chrome/browser/views/frame/contents_container.h
+++ b/chrome/browser/views/frame/contents_container.h
@@ -17,7 +17,7 @@ class Widget;
// ContentsContainer is responsible for managing the TabContents views.
// ContentsContainer has up to two children: one for the currently active
-// TabContents and one for the match preview TabContents.
+// TabContents and one for instant's TabContents.
class ContentsContainer : public views::View {
public:
ContentsContainer(BrowserView* browser_view, views::View* active);
diff --git a/chrome/browser/views/frame/browser_view.h b/chrome/browser/views/frame/browser_view.h
index ec9111d..71e99e3 100644
--- a/chrome/browser/views/frame/browser_view.h
+++ b/chrome/browser/views/frame/browser_view.h
@@ -321,9 +321,9 @@ class BrowserView : public BrowserBubbleHost,
virtual void Copy();
virtual void Paste();
virtual void ToggleTabStripMode();
- virtual void ShowMatchPreview(TabContents* preview_contents);
- virtual void HideMatchPreview();
- virtual gfx::Rect GetMatchPreviewBounds();
+ virtual void ShowInstant(TabContents* preview_contents);
+ virtual void HideInstant();
+ virtual gfx::Rect GetInstantBounds();
// Overridden from BrowserWindowTesting:
virtual BookmarkBarView* GetBookmarkBarView() const;
@@ -496,7 +496,7 @@ class BrowserView : public BrowserBubbleHost,
// Initialize the hung plugin detector.
void InitHangMonitor();
// Invoked from TabSelectedAt or when the match preview is made active. Is
// |change_tab_contents| is true, |new_contents| is added to the view
// hierarchy, if |change_tab_contents| is false, it's assumed |new_contents|
// has already been added to the view hierarchy.
@@ -584,7 +584,7 @@ class BrowserView : public BrowserBubbleHost,
// The view that contains devtools window for the selected TabContents.
TabContentsContainer* devtools_container_;
// The view that contains the match preview TabContents.
TabContentsContainer* preview_container_;
// The view managing both the contents_container_ and preview_container_.
@@ -496,7 +496,7 @@ class BrowserView : public BrowserBubbleHost,
// Initialize the hung plugin detector.
void InitHangMonitor();
- // Invoked from TabSelectedAt or when the match preview is made active. Is
+ // Invoked from TabSelectedAt or when instant is made active. Is
// |change_tab_contents| is true, |new_contents| is added to the view
// hierarchy, if |change_tab_contents| is false, it's assumed |new_contents|
@@ -584,7 +584,7 @@ class BrowserView : public BrowserBubbleHost,
// The view that contains devtools window for the selected TabContents.
TabContentsContainer* devtools_container_;
- // The view that contains the match preview TabContents.
+ // The view that contains instant's TabContents.
TabContentsContainer* preview_container_;
// The view managing both the contents_container_ and preview_container_.